# ja/add_bookmark.rb $Revision 1.3 $
#
# Japanese resource of add_bookmark.rb
#

@add_bookmark_label = '֥åޡɲ'
@add_bookmark_desc = 'ڡߤ󥯤åƤ'

@caption_hatena = 'ϤƤʥ֥åޡɲ'
@caption_del = 'del.icio.usɲ'
@caption_mm = 'MM/Memoɲ'

@bookmark_label = [
   'ϤƤʥ֥åޡ',
   'del.icio.us',
   'MM/Memo',
]
